==========================================
``psyclone.tests.psyir.frontend.conftest``
==========================================

.. automodule:: psyclone.tests.psyir.frontend.conftest

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.conftest
